@@ -117,6 +117,30 @@ void show_pos( int curr, int all )
   char t[64];
   sprintf( t, "%5d of %5d", curr, all );
   con_out( con_max_x() - 13, 3, t, cHEADER );
+
+  if( all == 0 ) return;
+
+  int x  = con_max_x();
+  int y1 = 4;
+  int y2 = con_max_y() - 2;
+
+  int y = y2 - y1;
+
+  if( all <= y ) return;
+  
+  int ss  = y * y / all;   // scroller size in scroll space
+  if( ss < 1 ) ss = 1;     // min scroller size
+  int vss = y - ss - 1;    // available scroll space without scroller size
+
+  int s1 = vss * curr / all; 
+  int s2 = s1 + ss;
+
+  // fprintf( stderr, "y %d, ss %d, vss %d, s1 %d, s2 %d\n", y, ss, vss, s1, s2 );
+
+  for( int z = 0; z < y; z++ )
+    {
+    con_out( x, y1 + z, " ", ( s1 <= z and z <= s2 ) ? CONCOLOR(cBLACK,cCYAN) : cNORMAL );
+    }
 }
 
 /*#######################################################################*/
